<?php

/**
 * @version     1.0.0
 * @package     com_callback
 * @copyright   Copyright (C) 2014. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Kennedy Kinoti <billing@intrepid.co.ke> - http://www.intrepid.co.ke
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Callback records.
 */
class CallbackModelVendors extends JModelList {

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                                'id', 'a.id',
                'vendor_id', 'a.vendor_id',
                'state', 'a.state',
                'mobilemoney', 'a.mobilemoney',
                'mobilebanking', 'a.mobilebanking',
                'creditcard', 'a.creditcard',

            );
        }

        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     */
    protected function populateState($ordering = null, $direction = null) {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        // Load the filter state.
        $search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $app->getUserStateFromRequest($this->context . '.filter.state', 'filter_published', '', 'string');
        $this->setState('filter.state', $published);

        
		//Filtering vendor_id
		$this->setState('filter.vendor_id', $app->getUserStateFromRequest($this->context.'.filter.vendor_id', 'filter_vendor_id', '', 'string'));

		//Filtering mobilemoney
		$this->setState('filter.mobilemoney', $app->getUserStateFromRequest($this->context.'.filter.mobilemoney', 'filter_mobilemoney', '', 'string'));

		//Filtering mobilebanking
		$this->setState('filter.mobilebanking', $app->getUserStateFromRequest($this->context.'.filter.mobilebanking', 'filter_mobilebanking', '', 'string'));

		//Filtering creditcard
		$this->setState('filter.creditcard', $app->getUserStateFromRequest($this->context.'.filter.creditcard', 'filter_creditcard', '', 'string'));


        // Load the parameters.
        $params = JComponentHelper::getParams('com_callback');
        $this->setState('params', $params);

        // List state information.
        parent::populateState('a.id', 'asc');
    }

    /**
     * Method to get a store id based on model configuration state.
     *
     * This is necessary because the model is used by the component and
     * different modules that might need different sets of data or different
     * ordering requirements.
     *
     * @param	string		$id	A prefix for the store id.
     * @return	string		A store id.
     * @since	1.6
     */
    protected function getStoreId($id = '') {
        // Compile the store id.
        $id.= ':' . $this->getState('filter.search');
        $id.= ':' . $this->getState('filter.state');

        return parent::getStoreId($id);
    }

    /**
     * Build an SQL query to load the list data.
     *
     * @return	JDatabaseQuery
     * @since	1.6
     */
    protected function getListQuery() {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select(
                $this->getState(
                        'list.select', 'a.*'
                )
        );
        $query->from('`#__callback_vendor` AS a');

        

        

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = ' . (int) $published);
		} else if ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

        // Filter by search in title
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int) substr($search, 3));
            } else {
                $search = $db->Quote('%' . $db->escape($search, true) . '%');
                
            }
        }

        

		//Filtering vendor_id

		//Filtering mobilemoney

		//Filtering mobilebanking

		//Filtering creditcard


        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering');
        $orderDirn = $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
            $query->order($db->escape($orderCol . ' ' . $orderDirn));
        }

        return $query;
    }

    public function getItems() {
        $items = parent::getItems();
        
        return $items;
    }

}
